do

local Config = import('/mods/kingofthehill/lua/kothConfig_HS.lua')

function switchConfig()
	Config = import('/mods/kingofthehill/lua/kothConfig_T.lua')
end

local GameMain = import('/lua/ui/game/gamemain.lua')
local UIUtil = import('/lua/ui/uiutil.lua')
local LayoutHelpers = import('/lua/maui/layouthelpers.lua')
local Group = import('/lua/maui/group.lua').Group
local Bitmap = import('/lua/maui/bitmap.lua').Bitmap
local Tooltip = import('/lua/ui/game/tooltip.lua')
local CreateAnnouncement = import('/lua/ui/game/announcement.lua').CreateAnnouncement

local VoteOptions = {}
local Votes = {}
local WinningVote = 0
local UI = false
local VoteTime = 10
local NumVotesIn = 0
local numLoops = 0

#### SIM TO UI STUFF ####

function SetVoteOptions( voteOptions)
    VoteOptions = voteOptions
    CreatekothUIButtons()
end

function SetVotes( votes)
    Votes = votes
end

function SetVoteTime( voteTime)
    VoteTime = voteTime
	--LOG('koth ui voteTime is', voteTime)
end

function SetNumVotesIn( numVotes)
    NumVotesIn = numVotes
    if UI then
        UI.voteCount.Update()
    end
end

function SetWinningVote( winningVote)
    WinningVote = winningVote
end

function ShowVoteUI()
    if UI then
        UI:Show()
        UI.voteTimeLeft.counterEndSec = GetGameTimeSeconds() + VoteTime
        GameMain.AddBeatFunction(UI.voteTimeLeft.UpdateFunc)  # enable the counter
    end
end

function HideVoteUI()
	--LOG('koth hiding 2')
    if UI then
        UI:Hide()
        GameMain.RemoveBeatFunction(UI.voteTimeLeft.UpdateFunc)  # disable the counter
    end
end

function AnnounceVoteOver()
    # create a 2 line announcement (like the one that says "no rush time over") and make it destroy the UI after
    # it's done cause after this we don't need the UI anymore.
    local text1 = Config.Text.Vote.VoteFinished
    local text2 = Config.Text.Vote.VoteResult[VoteOptions[WinningVote].announceText]
    local parent = import('/lua/ui/game/borders.lua').GetMapGroup()
    CreateAnnouncement(text1, parent, text2)
    DestroyUI()
end


#### koth UI STUFF ####

function Vote(option)
    data = {
        From = GetFocusArmy(),
        To = -1,
        Name = "kothVote",
        Args = { playerName = GetArmiesTable().armiesTable[GetFocusArmy()].nickname, option = option }
    }
    local QueryCb = function() end
    import('/lua/UserPlayerQuery.lua').Query( data, QueryCb )
end

function CreatekothUI()

    local parent = import('/lua/ui/game/borders.lua').GetMapGroup()

    # background
    UI = Bitmap(parent, UIUtil.UIFile(Config.Layout.VoteUI.BackgroundTexture))
    UI.Height:Set(function() return Config.Layout.VoteUI.BackgroundHeight end)
    UI.Width:Set(function() return Config.Layout.VoteUI.BackgroundWidth end)
    LayoutHelpers.AtCenterIn(UI, parent, Config.Layout.VoteUI.BackgroundYadj)

    # title
    UI.title = UIUtil.CreateText(UI, Config.Text.Vote.Dialog.Title, Config.Layout.VoteUI.TitleSize)
    LayoutHelpers.AtCenterIn(UI.title, UI, Config.Layout.VoteUI.TitleYadj)

    # subtext
    UI.subtext = UIUtil.CreateText(UI, Config.Text.Vote.Dialog.Subtitle, Config.Layout.VoteUI.SubtitleSize)
    LayoutHelpers.AtCenterIn(UI.subtext, UI, Config.Layout.VoteUI.SubtitleYadj)

    # the counter
    UI.voteTimeLeft = UIUtil.CreateText(UI, "", Config.Layout.VoteUI.CounterSize)
    LayoutHelpers.AtCenterIn(UI.voteTimeLeft, UI, Config.Layout.VoteUI.CounterYadj, Config.Layout.VoteUI.CounterXadj)
    UI.voteTimeLeft.counterEndSec = GetGameTimeSeconds() + VoteTime

    # this function updates the counter. But it's only used when the UI is visible (see show/hide functions above)
    UI.voteTimeLeft.UpdateFunc = function()
        local text = string.format( Config.Text.Vote.Dialog.Counter, math.floor(UI.voteTimeLeft.counterEndSec - GetGameTimeSeconds()))
        UI.voteTimeLeft:SetText( text )
    end    

    # the vote counter
    UI.voteCount = UIUtil.CreateText(UI, string.format(Config.Text.Vote.Dialog.VoteCounter, NumVotesIn), Config.Layout.VoteUI.VoteCounterSize)
    LayoutHelpers.AtCenterIn(UI.voteCount, UI, Config.Layout.VoteUI.VoteCounterYadj, Config.Layout.VoteUI.VoteCounterXadj)

    # this function updates the counter.
    UI.voteCount.Update = function()
        UI.voteCount:SetText(string.format(Config.Text.Vote.Dialog.VoteCounter, NumVotesIn))
    end

    # don't show UI just yet!
    UI:Hide()
end

function CreatekothUIButtons()

    if UI then
        UI.buttons = {}
        local i = 1
        local numButtons = table.getn(VoteOptions)
        local firstButtonXadj = math.floor((((
              ( Config.Layout.VoteUI.Button.Width + Config.Layout.VoteUI.Button.Spacing ) * numButtons) - 
                    Config.Layout.VoteUI.Button.Spacing) / -2 ) + Config.Layout.VoteUI.Button.Xadj + 
                   (Config.Layout.VoteUI.Button.Width/2) )

        for k, option in VoteOptions do

            local text = Config.Text.Button[option.btnText]
            local btn = UIUtil.CreateDialogButtonStd(UI, Config.Layout.VoteUI.Button.Texture, text, Config.Layout.VoteUI.Button.TextSize)
            btn.Width:Set(function() return Config.Layout.VoteUI.Button.Width end)

            if table.getn(UI.buttons) == 0 then
                LayoutHelpers.AtCenterIn( btn, UI, Config.Layout.VoteUI.Button.Yadj, firstButtonXadj)
            else
                LayoutHelpers.RightOf( btn, UI.buttons[(i-1)], Config.Layout.VoteUI.Button.Spacing)
            end

            btn.OnRolloverEvent = function(self, event)
                if event == 'enter' and Config.Layout.VoteUI.Button.RollOverSound then
                    PlaySound(Sound({Bank = 'Interface', Cue = Config.Layout.VoteUI.Button.RollOverSound}))
                end
            end
            btn.OnClick = function(self, modifiers)
                if Config.Layout.VoteUI.Button.OnClickSound then
                    PlaySound(Sound({ Bank = 'Interface', Cue = Config.Layout.VoteUI.Button.OnClickSound }))
                end
                Vote(self.kothVoteOption)
                UI:Hide()
            end

            btn.kothVoteOption = k

            UI.buttons[i] = btn
            i = i + 1
        end
    end
end

function DestroyUI()
	--LOG('koth destroy UI')
	if UI then
		HideVoteUI()
		UI:Destroy()
	end
	if numLoops == 0 then
		switchConfig()
		CreatekothUI()
		--LOG('koth new UI')
		numLoops = numLoops + 1
	end
end

function InitkothUI()
    if not SessionIsReplay() and not IsObserver() then
        CreatekothUI()
    end
end


end